==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Test/Gui/Resources/translations/Test_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Defecte şi erori</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Descriere</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Start</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt + S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Ajutor</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;Despre</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt + A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Inchide</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt + C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Liber</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Progres</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt; 0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Rămase:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Erori:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Defecte:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Rulează:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Selectaţi numele testului:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Ajutor</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>Despre FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer FreeCAD UnitTest este o parte a FreeCAD şi suportă definirea Unităţilor de Test pentru modulele proprii.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Test/Gui/Resources/translations/Test_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Defecte şi erori</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Descriere</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Start</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt + S</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Ajutor</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>&amp;Despre</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt + A</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Inchide</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt + C</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Liber</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Progres</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt; 0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Rămase:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Erori:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Defecte:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Rulează:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Selectaţi numele testului:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Ajutor</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>Despre FreeCAD UnitTest</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer FreeCAD UnitTest este o parte a FreeCAD şi suportă definirea Unităţilor de Test pentru modulele proprii.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Introduceti numele unui obiect apelabil ce creaza un TestCase. Apasati pe "start" pentru a rula testul rezultat.

Faceti dublu-click pe o eroare in vizualizarea arborescenta pentru mai multe informatii despre ea, incluzand istoria de apeluri.</translation>
    </message>
  </context>
</TS>
